fdasrsf
=======

C and Cython routines for functional data analysis using the square root
slope framework and curves using the square root velocity framework
which performs pair-wise and group-wise alignment as well as modelling
using functional component analysis and regression.

The code has been extracted from the repositories `fdasrsf_python
<https://github.com/jdtuck/fdasrsf_python>`_ and `ElasticFDA.jl
<https://github.com/jdtuck/ElasticFDA.jl>`_ developed by J. Derek Tucker.
A copy of the original license can be found `here
<LICENSE>`_.


References
==========
* Srivastava, A., Wu, W., Kurtek, S., Klassen, E. and Marron, J. S. (2011).
  Registration of Functional Data Using Fisher-Rao Metric.
  arXiv:1103.3817v2 [math.ST].

* Tucker, J. D., Wu, W. and Srivastava, A. (2013). Generative models for
  functional data using phase and amplitude separation. Computational Statistics
  and Data Analysis 61, 50-66.

* Joshi, S.H., Srivastava, A., Klassen, E. and Jermyn, I. (2007).
  A Novel Representation for Computing Geodesics Between n-Dimensional Elastic
  Curves. IEEE Conference on computer Vision and Pattern Recognition (CVPR),
  Minneapolis, MN.

* Srivastava, A., Klassen, E., Joshi, S., Jermyn, I., (2011). Shape analysis
  of elastic curves in euclidean spaces. Pattern Analysis and Machine
  Intelligence, IEEE Transactions on 33 (7), 1415 –1428.
